Function get_blob_params_by_spec_id
pub fn get_blob_params_by_spec_id(spec: SpecId) -> BlobParamsExpand description
Returns the blob params based on the spec id.
pub fn get_blob_params_by_spec_id(spec: SpecId) -> BlobParamsReturns the blob params based on the spec id.